@@ -31,19 +31,17 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 #
-from __future__ import absolute_import, annotations
+from __future__ import annotations
 
 import json
 import os
+import pickle  # noqa: S403
 import re
 import shutil
-import time
 from functools import reduce
 from tempfile import NamedTemporaryFile
 from typing import Dict, Iterable, List
 
-from six.moves import cPickle as pickle
-
 import univention.debug as ud
 
 import listener
@@ -56,6 +54,7 @@ attributes = ['univentionFetchmailSingle', 'univentionFetchmailMulti', 'uid', 'm
 modrdn = "1"
 
 fn_fetchmailrc = '/etc/fetchmailrc'
+__initscript = '/etc/init.d/fetchmail'
 FETCHMAIL_OLD_PICKLE = "/var/spool/univention-fetchmail/fetchmail_old_dn"
 
 UID_REGEX = re.compile("#UID='(.+)'[ \t]*$")
@@ -82,7 +81,7 @@ def load_rc(ofile: str) -> List[str] | None:
     try:
         with open(ofile) as fd:
             rc = reduce(_split_file, fd, [])
-    except EnvironmentError as exc:
+    except OSError as exc:
         ud.debug(ud.LISTENER, ud.ERROR, 'Failed to open "%s": %s' % (ofile, exc))
     listener.unsetuid()
     return rc
@@ -96,7 +95,7 @@ def write_rc(flist: Iterable[str], wfile: str) -> None:
             tmp_fd.writelines(flist)
             tmp_fd.close()
             shutil.move(tmp_fd.name, wfile)
-    except EnvironmentError as exc:
+    except OSError as exc:
         ud.debug(ud.LISTENER, ud.ERROR, 'Failed to write to file "%s": %s' % (wfile, exc))
     listener.unsetuid()
 
@@ -248,11 +247,10 @@ def handler(dn: str, new: Dict[str, List[bytes]], old: Dict[str, List[bytes]], c
 
 
 def postrun() -> None:
+    initscript = __initscript
     ud.debug(ud.LISTENER, ud.INFO, 'Restarting fetchmail-daemon')
     listener.setuid(0)
     try:
-        listener.run('systemctl', ['stop', 'fetchmail'], uid=0)
-        time.sleep(2)
-        listener.run('systemctl', ['start', 'fetchmail'], uid=0)
+        listener.run(initscript, ['fetchmail', 'restart'], uid=0)
     finally:
         listener.unsetuid()
